-- Author:svenp (sven.pegels@gmail.com)
-- Name:Crop Growth Stage Info
-- Description: Script mod for displaying the exact growth stage of the currently walked on field
-- Icon:
-- Hide: no
-- Credits to Yumi/Yumi-Modding's 'Additional Field Info' mod for showing the proper way of adding lines to the field info box

GrowthInfo = {};

function GrowthInfo:loadMap(name)
	print("Info - GrowthInfo: Loading mod")
end

function GrowthInfo:deleteMap(savegame)
	print("Info - GrowthInfo: Exiting")
end

function GrowthInfo:fieldAddFruit(data, box)
	if (self.fruitTypes == nil) then
		self.fruitTypes = g_currentMission.fruitTypeManager.indexToFruitType;
	end
	-- print("--- GrowthInfo: fieldAddFruit called");

	if (data == nil or box == nil) then
		do return end;
	end

	-- nil checks: when field does not contain a crop (plowed/cultivated), fruit data will be nil
	local fruitIndex = data.fruitTypeMax;
	if (fruitIndex ~= nil and data.fruits ~= nil) then
		local currentGrowthState = data.fruits[fruitIndex];
		local maxGrowthState = self.fruitTypes[fruitIndex].numGrowthStates - 1; -- numGrowthStates includes the harvesting state, therefore -1
		
		if (currentGrowthState ~= nil and currentGrowthState > 0 and currentGrowthState <= maxGrowthState) then
			-- Crop is in the one of the 'growing' states
			if (currentGrowthState >= self.fruitTypes[fruitIndex].minForageGrowthState) then
				-- Crop can be harvested by forage harvester already
				box:addLine(g_i18n:getText("label_Growth_Stage"), string.format("%s/%s (%s)", currentGrowthState, maxGrowthState, g_i18n:getText("text_Foragable")));
			else
				-- Crop cannot be harvested by forage harvester yet
				box:addLine(g_i18n:getText("label_Growth_Stage"), string.format("%s/%s", currentGrowthState, maxGrowthState));
			end
		end
	end
end
PlayerHUDUpdater.fieldAddFruit = Utils.appendedFunction(PlayerHUDUpdater.fieldAddFruit, GrowthInfo.fieldAddFruit);


if g_client ~= nil then
	-- client side mod only
	addModEventListener(GrowthInfo);
end
